@@ -1,9 +1,9 @@
 import datetime
 import logging
 
-from rumpy.client import FullNode, HttpRequest, LightNode
+from rumpy.client import FullNode, HttpRequest, LightNode, MiniNode
 
-__version__ = "0.6.4"
+__version__ = "0.7.0"
 __author__ = "liujuanjuan1984"
 
 # Set default logging handler to avoid "No handler found" warnings.
