@@ -1,12 +1,13 @@
 import base64
-from dataclasses import dataclass, field, asdict
 import json
 import logging
 import os
 import time
-from typing import Any, Dict, List, Union, Optional
+from dataclasses import asdict, dataclass, field
+from typing import Any, Dict, List, Optional, Union
 
 import filetype
+
 import rumpy.utils as utils
 from rumpy.exceptions import *
 
@@ -219,7 +220,7 @@ class ImgContent:
             self.name = utils.filename_init(path_bytes_string)
             file_bytes = utils.zip_image(path_bytes_string, kb)
             self.mediaType = filetype.guess(file_bytes).mime
-            self.content = base64.b64encode(file_bytes).decode("utf-8")
+            self.content = file_bytes  # TODO:临时修改，要确认是否可行。base64.b64encode(file_bytes).decode("utf-8")
 
     def person_img(self):
         return {"content": self.content, "mediaType": self.mediaType}
